//          Copyright Naoki Shibata 2010 - 2019.
// Distributed under the Boost Software License, Version 1.0.
//    (See accompanying file LICENSE.txt or copy at
//          http://www.boost.org/LICENSE_1_0.txt)

#ifndef __SLEEFQUAD_H__
#define __SLEEFQUAD_H__

#include "sleef.h"

#ifdef __cplusplus
extern "C"
{
#endif

#if (defined(__MINGW32__) || defined(__MINGW64__) || defined(__CYGWIN__) || defined(_MSC_VER)) && !defined(SLEEF_STATIC_LIBS)
#ifdef IMPORT_IS_EXPORT
#define IMPORT __declspec(dllexport)
#else // #ifdef IMPORT_IS_EXPORT
#define IMPORT __declspec(dllimport)
#if (defined(_MSC_VER))
#pragma comment(lib,"sleefquad.lib")
#endif // #if (defined(_MSC_VER))
#endif // #ifdef IMPORT_IS_EXPORT
#else // #if (defined(__MINGW32__) || defined(__MINGW64__) || defined(__CYGWIN__) || defined(_MSC_VER)) && !defined(SLEEF_STATIC_LIBS)
#define IMPORT
#endif // #if (defined(__MINGW32__) || defined(__MINGW64__) || defined(__CYGWIN__) || defined(_MSC_VER)) && !defined(SLEEF_STATIC_LIBS)

//

#if !defined(Sleef_quad_DEFINED)
#define Sleef_quad_DEFINED
#if defined(ENABLEFLOAT128)
typedef __float128 Sleef_quad;
#else
typedef struct { uint64_t x, y; } Sleef_quad;
#endif
#endif

#if !defined(Sleef_quad1_DEFINED)
#define Sleef_quad1_DEFINED
typedef union {
  struct {
    Sleef_quad x;
  };
  Sleef_quad s[1];
} Sleef_quad1;
#endif

#if !defined(Sleef_quad2_DEFINED)
#define Sleef_quad2_DEFINED
typedef union {
  struct {
    Sleef_quad x, y;
  };
  Sleef_quad s[2];
} Sleef_quad2;
#endif

#if !defined(Sleef_quad4_DEFINED)
#define Sleef_quad4_DEFINED
typedef union {
  struct {
    Sleef_quad x, y, z, w;
  };
  Sleef_quad s[4];
} Sleef_quad4;
#endif

#if !defined(Sleef_quad8_DEFINED)
#define Sleef_quad8_DEFINED
typedef union {
  Sleef_quad s[8];
} Sleef_quad8;
#endif

#if defined(__ARM_FEATURE_SVE) && !defined(Sleef_quadx_DEFINED)
#define Sleef_quadx_DEFINED
typedef union {
  Sleef_quad s[32];
} Sleef_quadx;
#endif

//

IMPORT Sleef_quad1 Sleef_strtoq(const char *str, char **endptr, int base);
IMPORT void Sleef_qtostr(char *s, int n, Sleef_quad1 a, int base);

//
#ifdef __STDC__
IMPORT CONST Sleef_quad1 Sleef_addq1_u05purec(Sleef_quad1, Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_subq1_u05purec(Sleef_quad1, Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_mulq1_u05purec(Sleef_quad1, Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_divq1_u05purec(Sleef_quad1, Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_negq1_purec(Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_sqrtq1_u05purec(Sleef_quad1);
IMPORT CONST int32_t Sleef_cmpltq1_purec(Sleef_quad1, Sleef_quad1);
IMPORT CONST int32_t Sleef_cmpleq1_purec(Sleef_quad1, Sleef_quad1);
IMPORT CONST int32_t Sleef_cmpgtq1_purec(Sleef_quad1, Sleef_quad1);
IMPORT CONST int32_t Sleef_cmpgeq1_purec(Sleef_quad1, Sleef_quad1);
IMPORT CONST int32_t Sleef_cmpeqq1_purec(Sleef_quad1, Sleef_quad1);
IMPORT CONST int32_t Sleef_cmpneqq1_purec(Sleef_quad1, Sleef_quad1);
IMPORT CONST int32_t Sleef_unordq1_purec(Sleef_quad1, Sleef_quad1);
IMPORT CONST double Sleef_cast_to_doubleq1_purec(Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_cast_from_doubleq1_purec(double);
IMPORT CONST Sleef_quad1 Sleef_sinq1_u10purec(Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_cosq1_u10purec(Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_tanq1_u10purec(Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_asinq1_u10purec(Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_acosq1_u10purec(Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_atanq1_u10purec(Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_expq1_u10purec(Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_exp2q1_u10purec(Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_exp10q1_u10purec(Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_expm1q1_u10purec(Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_logq1_u10purec(Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_log2q1_u10purec(Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_log10q1_u10purec(Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_log1pq1_u10purec(Sleef_quad1);
#endif
#ifdef FP_FAST_FMA
IMPORT CONST Sleef_quad1 Sleef_addq1_u05purecfma(Sleef_quad1, Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_subq1_u05purecfma(Sleef_quad1, Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_mulq1_u05purecfma(Sleef_quad1, Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_divq1_u05purecfma(Sleef_quad1, Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_negq1_purecfma(Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_sqrtq1_u05purecfma(Sleef_quad1);
IMPORT CONST int32_t Sleef_cmpltq1_purecfma(Sleef_quad1, Sleef_quad1);
IMPORT CONST int32_t Sleef_cmpleq1_purecfma(Sleef_quad1, Sleef_quad1);
IMPORT CONST int32_t Sleef_cmpgtq1_purecfma(Sleef_quad1, Sleef_quad1);
IMPORT CONST int32_t Sleef_cmpgeq1_purecfma(Sleef_quad1, Sleef_quad1);
IMPORT CONST int32_t Sleef_cmpeqq1_purecfma(Sleef_quad1, Sleef_quad1);
IMPORT CONST int32_t Sleef_cmpneqq1_purecfma(Sleef_quad1, Sleef_quad1);
IMPORT CONST int32_t Sleef_unordq1_purecfma(Sleef_quad1, Sleef_quad1);
IMPORT CONST double Sleef_cast_to_doubleq1_purecfma(Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_cast_from_doubleq1_purecfma(double);
IMPORT CONST Sleef_quad1 Sleef_sinq1_u10purecfma(Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_cosq1_u10purecfma(Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_tanq1_u10purecfma(Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_asinq1_u10purecfma(Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_acosq1_u10purecfma(Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_atanq1_u10purecfma(Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_expq1_u10purecfma(Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_exp2q1_u10purecfma(Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_exp10q1_u10purecfma(Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_expm1q1_u10purecfma(Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_logq1_u10purecfma(Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_log2q1_u10purecfma(Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_log10q1_u10purecfma(Sleef_quad1);
IMPORT CONST Sleef_quad1 Sleef_log1pq1_u10purecfma(Sleef_quad1);
#endif
#ifdef __SSE2__
IMPORT CONST Sleef_quad2 Sleef_addq2_u05sse2(Sleef_quad2, Sleef_quad2);
IMPORT CONST Sleef_quad2 Sleef_subq2_u05sse2(Sleef_quad2, Sleef_quad2);
IMPORT CONST Sleef_quad2 Sleef_mulq2_u05sse2(Sleef_quad2, Sleef_quad2);
IMPORT CONST Sleef_quad2 Sleef_divq2_u05sse2(Sleef_quad2, Sleef_quad2);
IMPORT CONST Sleef_quad2 Sleef_negq2_sse2(Sleef_quad2);
IMPORT CONST Sleef_quad2 Sleef_sqrtq2_u05sse2(Sleef_quad2);
IMPORT CONST __m128i Sleef_cmpltq2_sse2(Sleef_quad2, Sleef_quad2);
IMPORT CONST __m128i Sleef_cmpleq2_sse2(Sleef_quad2, Sleef_quad2);
IMPORT CONST __m128i Sleef_cmpgtq2_sse2(Sleef_quad2, Sleef_quad2);
IMPORT CONST __m128i Sleef_cmpgeq2_sse2(Sleef_quad2, Sleef_quad2);
IMPORT CONST __m128i Sleef_cmpeqq2_sse2(Sleef_quad2, Sleef_quad2);
IMPORT CONST __m128i Sleef_cmpneqq2_sse2(Sleef_quad2, Sleef_quad2);
IMPORT CONST __m128i Sleef_unordq2_sse2(Sleef_quad2, Sleef_quad2);
IMPORT CONST __m128d Sleef_cast_to_doubleq2_sse2(Sleef_quad2);
IMPORT CONST Sleef_quad2 Sleef_cast_from_doubleq2_sse2(__m128d);
IMPORT CONST Sleef_quad2 Sleef_sinq2_u10sse2(Sleef_quad2);
IMPORT CONST Sleef_quad2 Sleef_cosq2_u10sse2(Sleef_quad2);
IMPORT CONST Sleef_quad2 Sleef_tanq2_u10sse2(Sleef_quad2);
IMPORT CONST Sleef_quad2 Sleef_asinq2_u10sse2(Sleef_quad2);
IMPORT CONST Sleef_quad2 Sleef_acosq2_u10sse2(Sleef_quad2);
IMPORT CONST Sleef_quad2 Sleef_atanq2_u10sse2(Sleef_quad2);
IMPORT CONST Sleef_quad2 Sleef_expq2_u10sse2(Sleef_quad2);
IMPORT CONST Sleef_quad2 Sleef_exp2q2_u10sse2(Sleef_quad2);
IMPORT CONST Sleef_quad2 Sleef_exp10q2_u10sse2(Sleef_quad2);
IMPORT CONST Sleef_quad2 Sleef_expm1q2_u10sse2(Sleef_quad2);
IMPORT CONST Sleef_quad2 Sleef_logq2_u10sse2(Sleef_quad2);
IMPORT CONST Sleef_quad2 Sleef_log2q2_u10sse2(Sleef_quad2);
IMPORT CONST Sleef_quad2 Sleef_log10q2_u10sse2(Sleef_quad2);
IMPORT CONST Sleef_quad2 Sleef_log1pq2_u10sse2(Sleef_quad2);
#endif
#ifdef __AVX__
IMPORT CONST Sleef_quad4 Sleef_addq4_u05avx(Sleef_quad4, Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_subq4_u05avx(Sleef_quad4, Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_mulq4_u05avx(Sleef_quad4, Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_divq4_u05avx(Sleef_quad4, Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_negq4_avx(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_sqrtq4_u05avx(Sleef_quad4);
IMPORT CONST __m128i Sleef_cmpltq4_avx(Sleef_quad4, Sleef_quad4);
IMPORT CONST __m128i Sleef_cmpleq4_avx(Sleef_quad4, Sleef_quad4);
IMPORT CONST __m128i Sleef_cmpgtq4_avx(Sleef_quad4, Sleef_quad4);
IMPORT CONST __m128i Sleef_cmpgeq4_avx(Sleef_quad4, Sleef_quad4);
IMPORT CONST __m128i Sleef_cmpeqq4_avx(Sleef_quad4, Sleef_quad4);
IMPORT CONST __m128i Sleef_cmpneqq4_avx(Sleef_quad4, Sleef_quad4);
IMPORT CONST __m128i Sleef_unordq4_avx(Sleef_quad4, Sleef_quad4);
IMPORT CONST __m256d Sleef_cast_to_doubleq4_avx(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_cast_from_doubleq4_avx(__m256d);
IMPORT CONST Sleef_quad4 Sleef_sinq4_u10avx(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_cosq4_u10avx(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_tanq4_u10avx(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_asinq4_u10avx(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_acosq4_u10avx(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_atanq4_u10avx(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_expq4_u10avx(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_exp2q4_u10avx(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_exp10q4_u10avx(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_expm1q4_u10avx(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_logq4_u10avx(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_log2q4_u10avx(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_log10q4_u10avx(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_log1pq4_u10avx(Sleef_quad4);
#endif
#ifdef __AVX__
IMPORT CONST Sleef_quad4 Sleef_addq4_u05fma4(Sleef_quad4, Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_subq4_u05fma4(Sleef_quad4, Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_mulq4_u05fma4(Sleef_quad4, Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_divq4_u05fma4(Sleef_quad4, Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_negq4_fma4(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_sqrtq4_u05fma4(Sleef_quad4);
IMPORT CONST __m128i Sleef_cmpltq4_fma4(Sleef_quad4, Sleef_quad4);
IMPORT CONST __m128i Sleef_cmpleq4_fma4(Sleef_quad4, Sleef_quad4);
IMPORT CONST __m128i Sleef_cmpgtq4_fma4(Sleef_quad4, Sleef_quad4);
IMPORT CONST __m128i Sleef_cmpgeq4_fma4(Sleef_quad4, Sleef_quad4);
IMPORT CONST __m128i Sleef_cmpeqq4_fma4(Sleef_quad4, Sleef_quad4);
IMPORT CONST __m128i Sleef_cmpneqq4_fma4(Sleef_quad4, Sleef_quad4);
IMPORT CONST __m128i Sleef_unordq4_fma4(Sleef_quad4, Sleef_quad4);
IMPORT CONST __m256d Sleef_cast_to_doubleq4_fma4(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_cast_from_doubleq4_fma4(__m256d);
IMPORT CONST Sleef_quad4 Sleef_sinq4_u10fma4(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_cosq4_u10fma4(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_tanq4_u10fma4(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_asinq4_u10fma4(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_acosq4_u10fma4(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_atanq4_u10fma4(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_expq4_u10fma4(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_exp2q4_u10fma4(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_exp10q4_u10fma4(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_expm1q4_u10fma4(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_logq4_u10fma4(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_log2q4_u10fma4(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_log10q4_u10fma4(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_log1pq4_u10fma4(Sleef_quad4);
#endif
#ifdef __AVX__
IMPORT CONST Sleef_quad4 Sleef_addq4_u05avx2(Sleef_quad4, Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_subq4_u05avx2(Sleef_quad4, Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_mulq4_u05avx2(Sleef_quad4, Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_divq4_u05avx2(Sleef_quad4, Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_negq4_avx2(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_sqrtq4_u05avx2(Sleef_quad4);
IMPORT CONST __m128i Sleef_cmpltq4_avx2(Sleef_quad4, Sleef_quad4);
IMPORT CONST __m128i Sleef_cmpleq4_avx2(Sleef_quad4, Sleef_quad4);
IMPORT CONST __m128i Sleef_cmpgtq4_avx2(Sleef_quad4, Sleef_quad4);
IMPORT CONST __m128i Sleef_cmpgeq4_avx2(Sleef_quad4, Sleef_quad4);
IMPORT CONST __m128i Sleef_cmpeqq4_avx2(Sleef_quad4, Sleef_quad4);
IMPORT CONST __m128i Sleef_cmpneqq4_avx2(Sleef_quad4, Sleef_quad4);
IMPORT CONST __m128i Sleef_unordq4_avx2(Sleef_quad4, Sleef_quad4);
IMPORT CONST __m256d Sleef_cast_to_doubleq4_avx2(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_cast_from_doubleq4_avx2(__m256d);
IMPORT CONST Sleef_quad4 Sleef_sinq4_u10avx2(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_cosq4_u10avx2(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_tanq4_u10avx2(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_asinq4_u10avx2(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_acosq4_u10avx2(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_atanq4_u10avx2(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_expq4_u10avx2(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_exp2q4_u10avx2(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_exp10q4_u10avx2(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_expm1q4_u10avx2(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_logq4_u10avx2(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_log2q4_u10avx2(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_log10q4_u10avx2(Sleef_quad4);
IMPORT CONST Sleef_quad4 Sleef_log1pq4_u10avx2(Sleef_quad4);
#endif
#ifdef __AVX512F__
IMPORT CONST Sleef_quad8 Sleef_addq8_u05avx512f(Sleef_quad8, Sleef_quad8);
IMPORT CONST Sleef_quad8 Sleef_subq8_u05avx512f(Sleef_quad8, Sleef_quad8);
IMPORT CONST Sleef_quad8 Sleef_mulq8_u05avx512f(Sleef_quad8, Sleef_quad8);
IMPORT CONST Sleef_quad8 Sleef_divq8_u05avx512f(Sleef_quad8, Sleef_quad8);
IMPORT CONST Sleef_quad8 Sleef_negq8_avx512f(Sleef_quad8);
IMPORT CONST Sleef_quad8 Sleef_sqrtq8_u05avx512f(Sleef_quad8);
IMPORT CONST __m256i Sleef_cmpltq8_avx512f(Sleef_quad8, Sleef_quad8);
IMPORT CONST __m256i Sleef_cmpleq8_avx512f(Sleef_quad8, Sleef_quad8);
IMPORT CONST __m256i Sleef_cmpgtq8_avx512f(Sleef_quad8, Sleef_quad8);
IMPORT CONST __m256i Sleef_cmpgeq8_avx512f(Sleef_quad8, Sleef_quad8);
IMPORT CONST __m256i Sleef_cmpeqq8_avx512f(Sleef_quad8, Sleef_quad8);
IMPORT CONST __m256i Sleef_cmpneqq8_avx512f(Sleef_quad8, Sleef_quad8);
IMPORT CONST __m256i Sleef_unordq8_avx512f(Sleef_quad8, Sleef_quad8);
IMPORT CONST __m512d Sleef_cast_to_doubleq8_avx512f(Sleef_quad8);
IMPORT CONST Sleef_quad8 Sleef_cast_from_doubleq8_avx512f(__m512d);
IMPORT CONST Sleef_quad8 Sleef_sinq8_u10avx512f(Sleef_quad8);
IMPORT CONST Sleef_quad8 Sleef_cosq8_u10avx512f(Sleef_quad8);
IMPORT CONST Sleef_quad8 Sleef_tanq8_u10avx512f(Sleef_quad8);
IMPORT CONST Sleef_quad8 Sleef_asinq8_u10avx512f(Sleef_quad8);
IMPORT CONST Sleef_quad8 Sleef_acosq8_u10avx512f(Sleef_quad8);
IMPORT CONST Sleef_quad8 Sleef_atanq8_u10avx512f(Sleef_quad8);
IMPORT CONST Sleef_quad8 Sleef_expq8_u10avx512f(Sleef_quad8);
IMPORT CONST Sleef_quad8 Sleef_exp2q8_u10avx512f(Sleef_quad8);
IMPORT CONST Sleef_quad8 Sleef_exp10q8_u10avx512f(Sleef_quad8);
IMPORT CONST Sleef_quad8 Sleef_expm1q8_u10avx512f(Sleef_quad8);
IMPORT CONST Sleef_quad8 Sleef_logq8_u10avx512f(Sleef_quad8);
IMPORT CONST Sleef_quad8 Sleef_log2q8_u10avx512f(Sleef_quad8);
IMPORT CONST Sleef_quad8 Sleef_log10q8_u10avx512f(Sleef_quad8);
IMPORT CONST Sleef_quad8 Sleef_log1pq8_u10avx512f(Sleef_quad8);
#endif
#ifdef __cplusplus
}
#endif

#undef IMPORT
#endif // #ifndef __SLEEFQUAD_H__
